==> jc-1.4.0.tar.gz: java/security/GuardedObject.h <==
// public class java.security.GuardedObject

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9771700bad193e3d java_security_GuardedObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_GuardedObject_H_
#define _JC_java_security_GuardedObject_H_

// Forward structure declarations
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_Guard$object;

// Typedefs
typedef struct _jc_java_security_GuardedObject$sub_refs	_jc_java_security_GuardedObject$sub_refs;
typedef struct _jc_java_security_GuardedObject$sub_nonrefs	_jc_java_security_GuardedObject$sub_nonrefs;
typedef struct _jc_java_security_GuardedObject$refs	_jc_java_security_GuardedObject$refs;
typedef struct _jc_java_security_GuardedObject$nonrefs	_jc_java_security_GuardedObject$nonrefs;
typedef struct _jc_java_security_GuardedObject$object	_jc_java_security_GuardedObject$object;

typedef struct _jc_java_security_GuardedObject$fields_struct	_jc_java_security_GuardedObject$fields_struct;
typedef const struct _jc_java_security_GuardedObject$vmethods	_jc_java_security_GuardedObject$vmethods;
typedef const struct _jc_java_security_GuardedObject$vtable	_jc_java_security_GuardedObject$vtable;
typedef const struct _jc_java_security_GuardedObject$vtype	_jc_java_security_GuardedObject$vtype;

// Class fields structure
struct _jc_java_security_GuardedObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_GuardedObject$fields_struct _jc_java_security_GuardedObject$class_fields;

// Constructors
extern void _jc_java_security_GuardedObject$method$_init$57cb914048837bae(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_GuardedObject$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_java_security_GuardedObject$object *);
extern void _jc_java_security_GuardedObject$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_io_ObjectOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_GuardedObject$method_info$getObject$3a2eec332ceac060;
extern _jc_method _jc_java_security_GuardedObject$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_security_GuardedObject$vmethods {
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_java_security_GuardedObject$object *);
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_io_ObjectOutputStream$object *);
};

// Vtable
struct _jc_java_security_GuardedObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_GuardedObject$vmethods	java_security_GuardedObject;
};

// Vtype
struct _jc_java_security_GuardedObject$vtype {
	_jc_type			type;
	_jc_java_security_GuardedObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_GuardedObject$sub_refs {
	struct _jc_object	*guard;
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_java_security_GuardedObject$refs {
    _jc_java_security_GuardedObject$sub_refs	java_security_GuardedObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_GuardedObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_GuardedObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_GuardedObject$sub_nonrefs	java_security_GuardedObject;
};

// Object instance structure
struct _jc_java_security_GuardedObject$object {
	_jc_java_security_GuardedObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_GuardedObject$vtype	*vtype;
	_jc_java_security_GuardedObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_GuardedObject$vtype _jc_java_security_GuardedObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_GuardedObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_GuardedObject$class_object;

#endif	/* _JC_java_security_GuardedObject_H_ */

==> jc-1.4.6.tar.gz: java/security/GuardedObject.h <==
// public class java.security.GuardedObject

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9771700bad193e3d java_security_GuardedObject

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_GuardedObject_H_
#define _JC_java_security_GuardedObject_H_

// Forward structure declarations
struct _jc_java_io_ObjectOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_security_Guard$object;

// Typedefs
typedef struct _jc_java_security_GuardedObject$sub_refs	_jc_java_security_GuardedObject$sub_refs;
typedef struct _jc_java_security_GuardedObject$sub_nonrefs	_jc_java_security_GuardedObject$sub_nonrefs;
typedef struct _jc_java_security_GuardedObject$refs	_jc_java_security_GuardedObject$refs;
typedef struct _jc_java_security_GuardedObject$nonrefs	_jc_java_security_GuardedObject$nonrefs;
typedef struct _jc_java_security_GuardedObject$object	_jc_java_security_GuardedObject$object;

typedef struct _jc_java_security_GuardedObject$fields_struct	_jc_java_security_GuardedObject$fields_struct;
typedef const struct _jc_java_security_GuardedObject$vmethods	_jc_java_security_GuardedObject$vmethods;
typedef const struct _jc_java_security_GuardedObject$vtable	_jc_java_security_GuardedObject$vtable;
typedef const struct _jc_java_security_GuardedObject$vtype	_jc_java_security_GuardedObject$vtype;

// Class fields structure
struct _jc_java_security_GuardedObject$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_GuardedObject$fields_struct _jc_java_security_GuardedObject$class_fields;

// Constructors
extern void _jc_java_security_GuardedObject$method$_init$57cb914048837bae(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_GuardedObject$method$getObject$3a2eec332ceac060(_jc_env *, struct _jc_java_security_GuardedObject$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_GuardedObject$method$writeObject$6755db4c37bbfbcf(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_GuardedObject$method_info$getObject$3a2eec332ceac060;
extern _jc_method _jc_java_security_GuardedObject$method_info$writeObject$6755db4c37bbfbcf;

// Virtual methods structure
struct _jc_java_security_GuardedObject$vmethods {
	struct _jc_java_lang_Object$object	*(*getObject$3a2eec332ceac060)(_jc_env *, struct _jc_java_security_GuardedObject$object *) _JC_JCNI_ATTR;
	void	(*writeObject$6755db4c37bbfbcf)(_jc_env *, struct _jc_java_security_GuardedObject$object *, struct _jc_java_io_ObjectOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_GuardedObject$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_GuardedObject$vmethods	java_security_GuardedObject;
};

// Vtype
struct _jc_java_security_GuardedObject$vtype {
	_jc_type			type;
	_jc_java_security_GuardedObject$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_GuardedObject$sub_refs {
	struct _jc_object	*guard;
	struct _jc_java_lang_Object$object	*object;
};

// Reference instance fields (object)
struct _jc_java_security_GuardedObject$refs {
    _jc_java_security_GuardedObject$sub_refs	java_security_GuardedObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_GuardedObject$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_GuardedObject$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_GuardedObject$sub_nonrefs	java_security_GuardedObject;
};

// Object instance structure
struct _jc_java_security_GuardedObject$object {
	_jc_java_security_GuardedObject$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_GuardedObject$vtype	*vtype;
	_jc_java_security_GuardedObject$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_GuardedObject$vtype _jc_java_security_GuardedObject$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_GuardedObject, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_GuardedObject$class_object;

#endif	/* _JC_java_security_GuardedObject_H_ */
